@@ -3,7 +3,7 @@ BEGIN {
   $MooseX::Getopt::OptionTypeMap::AUTHORITY = 'cpan:STEVAN';
 }
 # ABSTRACT: Storage for the option to type mappings
-$MooseX::Getopt::OptionTypeMap::VERSION = '0.63';
+$MooseX::Getopt::OptionTypeMap::VERSION = '0.65';
 use Moose;
 use Carp 'confess';
 use Scalar::Util 'blessed';
@@ -99,20 +99,13 @@ __END__
 
 =encoding UTF-8
 
-=for :stopwords Stevan Little Infinity Interactive, Inc Brandon Devin Austin Drew Taylor
-Florian Ragwitz Gordon Irving Hans Dieter L Pearcey Hinrik Örn Sigurðsson
-Jesse Luehrs John Goulah Jonathan Swartz Black Justin Hunter Karen
-Etheridge Nelo Onyiah Ricardo SIGNES Ryan D Chris Johnson Shlomi Fish Todd
-Hepler Tomas Doran Yuval Prather Kogman Ævar Arnfjörð Bjarmason Dagfinn
-Ilmari Mannsåker Damien Krotkine
-
 =head1 NAME
 
 MooseX::Getopt::OptionTypeMap - Storage for the option to type mappings
 
 =head1 VERSION
 
-version 0.63
+version 0.65
 
 =head1 DESCRIPTION
 
